# MPL BSIC Package

## Read Docs

1. Download the docs.pdf file (TODO)
2. Hosted docs (TODO) 

## If the matplotlib fonts does not work

You have to install the .ttf and clean your matplotlib cache (full guide to come)
